@@ -14,9 +14,18 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 非企业认证客户。
 AUTHFAILURE_NOTENTERPRISEAUTHORIZATION = 'AuthFailure.NotEnterpriseAuthorization'
 
+# 子账户未授权操作。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
+# DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
+DRYRUNOPERATION = 'DryRunOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -32,9 +41,15 @@ FAILEDOPERATION_ACTIONOPERATETOOQUICKLY = 'FailedOperation.ActionOperateTooQuick
 # 该批通道归属于不同的通道组，无法批量操作。
 FAILEDOPERATION_BELONGDIFFERENTGROUP = 'FailedOperation.BelongDifferentGroup'
 
+# 中国电信加速token过期。
+FAILEDOPERATION_CTCCTOKENEXPIRED = 'FailedOperation.CTCCTokenExpired'
+
 # 证书正在使用中，无法操作。
 FAILEDOPERATION_CERTIFICATEISUSING = 'FailedOperation.CertificateIsUsing'
 
+# 相同加速间隔时间过短。
+FAILEDOPERATION_CREATEQOSEXCEEDLIMIT = 'FailedOperation.CreateQosExceedLimit'
+
 # 通道组中存在通道，无法删除。
 FAILEDOPERATION_DELETEPROXYGROUPPROXYREMAINED = 'FailedOperation.DeleteProxyGroupProxyRemained'
 
@@ -50,6 +65,9 @@ FAILEDOPERATION_DUPLICATEDREQUEST = 'FailedOperation.DuplicatedRequest'
 # 通道组状态为非运行状态，无法操作。
 FAILEDOPERATION_GROUPSTATUSNOTINRUNING = 'FailedOperation.GroupStatusNotInRuning'
 
+# 加速目标IP与绑定的通道IP不匹配。
+FAILEDOPERATION_IPUNMATCHED = 'FailedOperation.IPUnmatched'
+
 # 通道状态为非运行状态，无法操作。
 FAILEDOPERATION_INSTANCESTATUSNOTINRUNING = 'FailedOperation.InstanceStatusNotInRuning'
 
@@ -74,6 +92,15 @@ FAILEDOPERATION_LISTENERHASTASK = 'FailedOperation.ListenerHasTask'
 # 监听器当前状态无法支持该操作。
 FAILEDOPERATION_LISTENERSTATUSERROR = 'FailedOperation.ListenerStatusError'
 
+# 加速通道在升级中，暂不支持配置变更，请提工单申请。
+FAILEDOPERATION_MIGRATION = 'FailedOperation.Migration'
+
+# 该应用模版没有绑定通道。
+FAILEDOPERATION_NORESOURCEBOUND = 'FailedOperation.NoResourceBound'
+
+# 该通道为非标通道，限制所有写操作。
+FAILEDOPERATION_NONSTANDARDPROXY = 'FailedOperation.NonStandardProxy'
+
 # 仅支持Version2.0的通道。
 FAILEDOPERATION_NOTSUPPORTOLDVERSIONPROXY = 'FailedOperation.NotSupportOldVersionProxy'
 
@@ -101,6 +128,9 @@ FAILEDOPERATION_PROXYSECURITYPOLICYDUPLICATEDRULE = 'FailedOperation.ProxySecuri
 # 安全策略已经存在，请勿重复创建。
 FAILEDOPERATION_PROXYSECURITYPOLICYEXISTED = 'FailedOperation.ProxySecurityPolicyExisted'
 
+# 通道安全策略操作中。
+FAILEDOPERATION_PROXYSECURITYPOLICYOPERATING = 'FailedOperation.ProxySecurityPolicyOperating'
+
 # 线路售罄或资源不足，请提工单申请。
 FAILEDOPERATION_PROXYSELLOUT = 'FailedOperation.ProxySellOut'
 
@@ -116,18 +146,48 @@ FAILEDOPERATION_REALSERVERALREADYBOUND = 'FailedOperation.RealServerAlreadyBound
 # 源站不归属于该项目。
 FAILEDOPERATION_REALSERVERNOTINPROJECT = 'FailedOperation.RealServerNotInProject'
 
+# 请求运营商超时。
+FAILEDOPERATION_REQUESTVENDORTIMEOUT = 'FailedOperation.RequestVendorTimeout'
+
 # 该资源不可访问。
 FAILEDOPERATION_RESOURCECANNOTACCESS = 'FailedOperation.ResourceCanNotAccess'
 
+# 资源已经被操作过。
+FAILEDOPERATION_RESOURCEHADBEENDONE = 'FailedOperation.ResourceHadBeenDone'
+
+# 应用ID填写有误，请检查应用ID是否存在。
+FAILEDOPERATION_RESOURCENOTFOUND = 'FailedOperation.ResourceNotFound'
+
 # 资源升级中。
 FAILEDOPERATION_RESOURCEUPGRADING = 'FailedOperation.ResourceUpgrading'
 
 # 规则已经存在。
 FAILEDOPERATION_RULEALREADYEXISTED = 'FailedOperation.RuleAlreadyExisted'
 
+# Session不存在或已经被取消。
+FAILEDOPERATION_SESSIONNOTEXIST = 'FailedOperation.SessionNotExist'
+
+# 标签资源绑定失败。
+FAILEDOPERATION_TAGRESOURCESFAILED = 'FailedOperation.TagResourcesFailed'
+
+# 标签资源解绑失败。
+FAILEDOPERATION_UNTAGRESOURCESFAILED = 'FailedOperation.UnTagResourcesFailed'
+
 # 用户未认证。
 FAILEDOPERATION_USERNOTAUTHENTICATED = 'FailedOperation.UserNotAuthenticated'
 
+# 未开通协议。
+FAILEDOPERATION_USERNOTCONFIRMPROTOCOL = 'FailedOperation.UserNotConfirmProtocol'
+
+# 该用户不在运营商网络可加速范围内。
+FAILEDOPERATION_USEROUTOFCOVERAGE = 'FailedOperation.UserOutOfCoverage'
+
+# 运营商返回结果错误。
+FAILEDOPERATION_VENDORRETURNERROR = 'FailedOperation.VendorReturnError'
+
+# 运营商服务器临时错误。
+FAILEDOPERATION_VENDORSERVERERROR = 'FailedOperation.VendorServerError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -152,6 +212,12 @@ INVALIDPARAMETERVALUE_DUPLICATERS = 'InvalidParameterValue.DuplicateRS'
 # 监听器端口已存在。
 INVALIDPARAMETERVALUE_DUPLICATEDLISTENERPORT = 'InvalidParameterValue.DuplicatedListenerPort'
 
+# 无法同时开启所设置的特性。
+INVALIDPARAMETERVALUE_FEATURECONFLICT = 'InvalidParameterValue.FeatureConflict'
+
+# 资源已被录入封禁黑名单。
+INVALIDPARAMETERVALUE_HITBANBLACKLIST = 'InvalidParameterValue.HitBanBlacklist'
+
 # header黑名单限制。
 INVALIDPARAMETERVALUE_HITBLACKLIST = 'InvalidParameterValue.HitBlacklist'
 
@@ -176,9 +242,18 @@ INVALIDPARAMETERVALUE_INVALIDLISTENERPORT = 'InvalidParameterValue.InvalidListen
 # 未找到或无权限访问该标签
 INVALIDPARAMETERVALUE_INVALIDTAGS = 'InvalidParameterValue.InvalidTags'
 
+# 该域名被封禁，无法添加。
+INVALIDPARAMETERVALUE_L7DOMAINHITBANBLACKLIST = 'InvalidParameterValue.L7DomainHitBanBlacklist'
+
 # 项目不属于该用户。
 INVALIDPARAMETERVALUE_PROJECTIDNOTBELONG = 'InvalidParameterValue.ProjectIdNotBelong'
 
+# 该通道组下无法支持该通道所需的特性。
+INVALIDPARAMETERVALUE_PROXYANDGROUPFEATURECONFLICT = 'InvalidParameterValue.ProxyAndGroupFeatureConflict'
+
+# 该地区不支持通道所设置的特性。
+INVALIDPARAMETERVALUE_PROXYANDREGIONFEATURECONFLICT = 'InvalidParameterValue.ProxyAndRegionFeatureConflict'
+
 # 源站不属于该用户。
 INVALIDPARAMETERVALUE_REALSERVERNOTBELONG = 'InvalidParameterValue.RealServerNotBelong'
 
@@ -191,6 +266,9 @@ INVALIDPARAMETERVALUE_UNKNOWNDESTREGION = 'InvalidParameterValue.UnknownDestRegi
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 标签配额不足。
+LIMITEXCEEDED_TAGQUOTA = 'LimitExceeded.TagQuota'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -206,6 +284,9 @@ RESOURCEUNAVAILABLE_ACCOUNTVIOLATION = 'ResourceUnavailable.AccountViolation'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 跨境通道的联通带宽处于隔离中。
+UNAUTHORIZEDOPERATION_CROSSBORDERINISOLATING = 'UnauthorizedOperation.CrossBorderInIsolating'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
